==> camel-k-model-v1alpha1-6.1.1-sources.jar: io/fabric8/camelk/v1alpha1/ExternalDocumentationFluentImpl.java <==
package io.fabric8.camelk.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExternalDocumentationFluentImpl<A extends ExternalDocumentationFluent<A>> extends BaseFluent<A> implements ExternalDocumentationFluent<A>{
  public ExternalDocumentationFluentImpl() {
  }
  public ExternalDocumentationFluentImpl(ExternalDocumentation instance) {
    this.withDescription(instance.getDescription()); 
    this.withUrl(instance.getUrl()); 
  }
  private String description;
  private String url;
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ExternalDocumentationFluentImpl that = (ExternalDocumentationFluentImpl) o;
    if (description != null ? !description.equals(that.description) :that.description != null) return false;
    if (url != null ? !url.equals(that.url) :that.url != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> camel-k-model-v1alpha1-6.7.2-sources.jar: io/fabric8/camelk/v1alpha1/ExternalDocumentationFluentImpl.java <==
package io.fabric8.camelk.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ExternalDocumentationFluentImpl<A extends ExternalDocumentationFluent<A>> extends BaseFluent<A> implements ExternalDocumentationFluent<A>{
  public ExternalDocumentationFluentImpl() {
  }
  public ExternalDocumentationFluentImpl(ExternalDocumentation instance) {
    if (instance != null) {
      this.withDescription(instance.getDescription());
      this.withUrl(instance.getUrl());
    }
  }
  private String description;
  private String url;
  public String getDescription() {
    return this.description;
  }
  public A withDescription(String description) {
    this.description=description; return (A) this;
  }
  public Boolean hasDescription() {
    return this.description != null;
  }
  public String getUrl() {
    return this.url;
  }
  public A withUrl(String url) {
    this.url=url; return (A) this;
  }
  public Boolean hasUrl() {
    return this.url != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ExternalDocumentationFluentImpl that = (ExternalDocumentationFluentImpl) o;
    if (!java.util.Objects.equals(description, that.description)) return false;

    if (!java.util.Objects.equals(url, that.url)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(description,  url,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (description != null) { sb.append("description:"); sb.append(description + ","); }
    if (url != null) { sb.append("url:"); sb.append(url); }
    sb.append("}");
    return sb.toString();
  }
  
}
